phitigra: A graph editor for SageMath/Jupyter
=============================================

Description
-----------

A graph editor for SageMath/Jupyter

License
-------

Upstream Contact
----------------

https://pypi.org/project/phitigra/

